==> pylucene-9.7.0-src.tar.gz: pylucene-9.7.0/extensions/src/java/org/apache/pylucene/util/PythonAttributeImpl.java <==
/* ====================================================================
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

package org.apache.pylucene.util;

import org.apache.lucene.util.AttributeImpl;
import org.apache.lucene.util.AttributeReflector;

public class PythonAttributeImpl extends AttributeImpl {
    private long pythonObject;

    public PythonAttributeImpl()
    {
    }

    public void pythonExtension(long pythonObject)
    {
        this.pythonObject = pythonObject;
    }
    public long pythonExtension()
    {
        return this.pythonObject;
    }

    public void finalize()
        throws Throwable
    {
        pythonDecRef();
    }

    public native void pythonDecRef();

    @Override
    public native void clear();
    @Override
    public native void copyTo(AttributeImpl target);
    @Override
    public native void reflectWith(AttributeReflector reflector);

    @Override
    public native boolean equals(Object obj);
    @Override
    public native int hashCode();
}

==> pylucene-10.0.0-src.tar.gz: pylucene-10.0.0/extensions/src/java/org/apache/pylucene/util/PythonAttributeImpl.java <==
/* ====================================================================
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

package org.apache.pylucene.util;

import org.apache.lucene.util.AttributeImpl;
import org.apache.lucene.util.AttributeReflector;
import org.apache.pylucene.ref.PythonObject;
import org.apache.pylucene.ref.PythonObjectManager;

public class PythonAttributeImpl extends AttributeImpl {
    private PythonObject pythonObject;

    public PythonAttributeImpl()
    {
    }

    public void pythonExtension(long pythonObject)
    {
        this.pythonObject = PythonObjectManager.register(pythonObject);
    }
    public long pythonExtension()
    {
        return this.pythonObject.pythonObject;
    }

    @Override
    public native void clear();
    @Override
    public native void copyTo(AttributeImpl target);
    @Override
    public native void reflectWith(AttributeReflector reflector);

    @Override
    public native boolean equals(Object obj);
    @Override
    public native int hashCode();
}
